[LyX/2.3.x] Fixup 7485225c: better placement of deph bar

Richard Kimberly Heck rikiheck at lyx.org
Wed Nov 23 01:19:10 UTC 2022


commit 483d4466fd23ccf0a2afaa9c4d31b60a1ed6e9bf
Author: Jean-Marc Lasgouttes <lasgouttes at lyx.org>
Date:   Wed Jan 19 18:08:47 2022 +0100

    Fixup 7485225c: better placement of deph bar
    
    Fixes #12243.
    
    (cherry picked from commit a64244b844e613aa0f739e050aa23168ff21fce9)
---
 src/RowPainter.cpp |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/RowPainter.cpp b/src/RowPainter.cpp
index cc3ea89..81769c9 100644
--- a/src/RowPainter.cpp
+++ b/src/RowPainter.cpp
@@ -313,9 +313,9 @@ void RowPainter::paintDepthBar() const
 	for (depth_type i = 1; i <= depth; ++i) {
 		int const w = nestMargin() / 5;
 		int x = int(xo_) + w * i;
 		// consider the bufferview left margin if we're drawing outermost text
 		if (text_.isMainText())
-			x += pi_.base.bv->leftMargin();
+			x += pi_.base.bv->leftMargin() - changebarMargin();
 
 		int const starty = yo_ - row_.ascent();
 		int const h =  row_.height() - 1 - (i - next_depth - 1) * 3;
@@ -313,9 +313,9 @@ void RowPainter::paintDepthBar() const
 		int const w = nestMargin() / 5;
 		int x = int(xo_) + w * i;
-		// consider the bufferview left margin if we're drawing outermost text
+		// only consider the changebar space if we're drawing outermost text
 		if (text_.isMainText())


More information about the lyx-cvs mailing list